<?php
/**
 * Initialize Class
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 * @package WordPress
 */

class UBC_WP_CLF_Lite {

	/**
	 * Set up our actions and filters
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return void
	 * @package WordPress
	 */
	public function init() {

		// Enqueue Scripts
		add_action( 'wp_enqueue_scripts', array( $this, 'load_ubc_wp_clf_lite_scripts' ), 10, 2 );

		add_action( 'wp_enqueue_scripts', array( $this, 'load_ubc_wp_clf_lite_styles' ), 10, 2 );

		// denque Advanced Quiz Stylesheet
		add_action( 'wp_print_styles', array( $this, 'dequeue_advanced_quiz_style' ), 10, 2 );

		// Adds excerpt to pages
		add_action( 'init', array( $this, 'my_add_excerpts_to_pages' ), 10, 2 );

		// Add the notes form
		add_action( 'wp_clf_lite_sidebar_notes', array( $this, 'wp_clf_lite_sidebar_notes__notes_form' ) );

		// Add the Handouts tab
		add_action( 'wp_clf_lite_sidebar_handouts', array( $this, 'wp_clf_lite_sidebar_handouts__handouts_markup' ) );

		// Add do action for course section listings
		add_action( 'sections_page_listing', array( $this, 'course_sidebar_sections_list_sections' ), 10, 2 );

		// Add to show courses sections and child sections listings
		add_action( 'sections_course_main_listing', array( $this, 'list_sections_with_subsections' ), 10, 2 );

		// surrounds specified oembed content with html
		add_filter( 'embed_oembed_html', array( $this, 'tdd_oembed_filter' ), 99, 4 );

		add_action( 'widgets_init', 'wp_clf_lite_widgets_init' );

		// Teeny mce remove buttons
		add_filter( 'teeny_mce_buttons', array( $this, 'remove_bold_tinymce_button' ) );

		add_filter( 'teeny_mce_before_init', array( $this, 'style_frontend_tinyce' ) );

		add_filter( 'pre_do_shortcode_tag', array( $this, 'pre_do_shortcode_tag__enqueue_bbpress_styles' ), 1, 4 );

	}/* init() */


	public function pre_do_shortcode_tag__enqueue_bbpress_styles( $return, $tag, $attr, $m ) {

		if ( 'bbp-single-forum' !== $tag && 'bbp-single-topic' !== $tag ) {
			return $return;
		}

		wp_register_style(
		    'ubc-bbpress',
		    get_stylesheet_directory_uri() . '/css/bbpress.css',
		    'null',
		    '1.0',
		    'screen'
		);
		wp_enqueue_style( 'ubc-bbpress' );

		return $return;

	}/* pre_do_shortcode_tag__enqueue_bbpress_styles() */


	/**
	 * Remove unused scripts from Teeny mce
	 *
	 * @since 0.1.9
	 * @return $in = array of avaible options
	 */
	public function style_frontend_tinyce( $in ) {

		if ( ! is_admin() ) :

			$in['plugins'] = 'fullscreen';

				return $in;

		endif;

	}

	/**
	 * Remove buttons from teeny mce
	 *
	 * @since 0.1.9
	 * @param $buttons = array of avaible buttons
	 * @return $remove = array of button to remove
	 */
	public function remove_bold_tinymce_button( $buttons ) {

		if ( ! is_admin() ) :

			//Remove unwanted buttons
			$remove = array( 'blockquote', 'alignleft', 'strikethrough', 'aligncenter', 'alignright', 'undo', 'redo', 'link', 'unlink' );

				return array_diff( $buttons, $remove );

		endif;
	}

	/**
	 * Register widget area.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
	 */
	public function wp_clf_lite_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'ubc-wp-clf-lite' ),
			'id'            => 'sidebar-1',
			'description'   => '',
			'before_widget' => '<section id="%1$s" class="widget %2$s small-12 column">',
			'after_widget'  => '</section>',
			'before_title'  => '<h1 class="widget-title">',
			'after_title'   => '</h1>',
		) );
	}

	/**
	 * denque advanced quizes
	 *
	 * @since 1.0.0
	 * @return null
	 */

	public function dequeue_advanced_quiz_style() {

		wp_dequeue_style( 'wpProQuiz_front_style' );
		wp_dequeue_style( 'bbp-default' );

	}/** dequeue_advanced_quiz_style() **/

	/**
	 * Adding excerpts to pages
	 *
	 * @since 1.0.0
	 * @return null
	 */

	public function my_add_excerpts_to_pages() {

		add_post_type_support( 'page', 'excerpt' );

	}

	/**
	 * Registering and enqueing scripts
	 *
	 * @since 1.0.0
	 * @return null
	 */

	public function load_ubc_wp_clf_lite_scripts() {

		//registering scripts
		wp_register_script( 'foundation-default-js',
			get_stylesheet_directory_uri() . '/js/app.js',
			array( 'jquery' ),
			1.0, true
		);

		wp_register_script( 'ie9_below', get_stylesheet_directory_uri() . '/js/flexibility.js' );

		$GLOBALS['wp_scripts']->add_data( 'ie9_below', 'conditional', 'IE 9' );

		wp_enqueue_script( 'ie9_below' );

		//enqueuing scripts
		wp_enqueue_script( 'foundation-default-js' );

	}/* load_ubc_wp_clf_lite_styles_scripts() */

	/**
	 * Registering and enqueing styles
	 *
	 * @since 1.0.0
	 * @return null
	 */

	public function load_ubc_wp_clf_lite_styles() {

		wp_register_style( 'whiteny-font', '//cloud.typography.com/6804272/697806/css/fonts.css', null, 1.0, 'screen' );

		wp_enqueue_style( 'whiteny-font' );

		wp_register_style(
		    'main-site',
		    get_stylesheet_directory_uri() . '/css/app.css',
		    'null',
		    '1.0',
		    'screen'
		);

		wp_register_style(
		    'ubc-bbpress',
		    get_stylesheet_directory_uri() . '/css/bbpress.css',
		    'null',
		    '1.0',
		    'screen'
		);

		if ( is_bbpress() ) :

			wp_enqueue_style( 'ubc-bbpress' );

		endif;

		wp_enqueue_style( 'main-site' );

		wp_register_style(
		    'ie9-grid',
		    get_stylesheet_directory_uri() . '/css/ie9-grid.css',
		    'null',
		    '1.0',
		    'screen'
		);

	    wp_enqueue_style( 'ie9-grid' );
	   	$GLOBALS['wp_styles']->add_data( 'ie9-grid', 'conditional', 'IE 9' );

	}


	/*  add html around specified oembed objects tdd_oembed_filter() */

	function tdd_oembed_filter($html, $url, $attr, $post_ID) {

		if ( strpos( $html, 'youtube' ) !== false || strpos( $html, 'vimeo' ) !== false  ) :

		 	return  '<div class="flex-video">'.$html.'</div>';

		else :

			return $html;

	endif;

	}/* tdd_oembed_filter() */

	/**
	 * The markup for the notes form in the sidebar.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	function wp_clf_lite_sidebar_notes__notes_form() {

		if ( ! is_user_logged_in() ) {
			$login_url = wp_login_url( get_permalink() );
			echo '<div class="no-notes column">';
			$sign_in_link = '<a class="button tiny hollow" href="' . $login_url . '" title="">' . __( 'sign in', 'ubc-wp-clf-lite' ) . '</a>';
			echo wp_kses_post( sprintf( _x( 'Notes only available if you %s', '%s = sign in link', 'ubc-wp-clf-lite' ), $sign_in_link ) );
			echo '</div>';
			return;
		}

		global $post;

		// Fetch the actual form from CMB2
		$form = cmb2_get_metabox_form( 'ubc_user_notes_metabox', $post->ID );

		echo $form;

	}/* wp_clf_lite_sidebar_notes__notes_form() */


	/**
	 * The main sidebar contains 3 tabs; Sections, Handouts and Notes
	 * This is the markup for the 2nd tab - Handouts. IT displays a list
	 * of the handouts that are for the currently shown subsection.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function wp_clf_lite_sidebar_handouts__handouts_markup() {

		global $post;

		if ( ! is_a( $post, 'WP_Post' ) ) {
			return;
		}

		$handouts = static::get_handouts_for_subsection( $post );

		if ( false === $handouts ) {
			echo esc_html( 'No Handouts available', 'ubc-wp-clf-lite' );
			return;
		}

		$startPath = trailingslashit( dirname( __FILE__ ) ) . 'template-parts';
		$templateNames = 'handout-tab-single.php';

		echo '<ul>';

		foreach ( $handouts as $id => $handout_items ) {
			\UBC\Helpers::locate_template_part_in_plugin( $startPath, $templateNames, true, false, $handout_items );
		}

		echo '</ul>';

	}/* wp_clf_lite_sidebar_handouts__handouts_markup() */

	/**
	 * Helper function to get the handouts attached to a subsection
	 *
	 * @since 1.0.0
	 *
	 * @param (Object|Int) $post - A WP_Post Object or a post ID
	 * @return (false|array) - The handouts attached to the passed subsection, false if none found
	 */

	public static function get_handouts_for_subsection( $post ) {

		// If what is passed is not a WP_Post object, assume a post ID
		if ( ! is_a( $post, 'WP_Post' ) ) {
			$section_post_id = absint( $post );
		}

		$section_post_id = $post->ID;

		if ( empty( $section_post_id ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		$component_associations = get_post_meta( $section_post_id, 'component_associations', true );

		if ( empty( $component_associations ) || ! is_array( $component_associations ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		$handouts = array();

		// Test if any of these are handouts
		foreach ( $component_associations as $id => $post_id ) {

			$post_type = get_post_type( $post_id );
			if ( 'handout' !== $post_type ) {
				continue;
			}

			$handouts[ $post_id ] = array(

				'title' => get_the_title( $post_id ),
				'fields' => \UBC\Press\Utils::get_handout_content( $post_id ),

			);

		}

		if ( empty( $handouts ) ) {
			return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', false );
		}

		return apply_filters( 'ubc_wp_clf_lite_handouts_for_subsection', $handouts );

	}/* get_handouts_for_subsection() */


	/**
	 * Courses sidebar sections page list. Sets up loop query $sections_list_query and includes template courses-section-list.php
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function course_sidebar_sections_list_sections() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/inc/sidebar-sub-section-list.php' );

	}/* course_sidebar_sections_list_sections */

	/**
	 * List sections with subsections.
	 *
	 * @since 1.0.0
	 *
	 * @param null
	 * @return null
	 */

	public function list_sections_with_subsections() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/inc/sub-section-list.php' );

	}/* list_sections_with_subsections() */

}/* class UBC_CLF_Lite() */

// Initialize our child theme changes
add_action( 'after_setup_theme', 'after_setup_theme__ubc_clf_lite_init', 15 );

/**
 * Initialize the UBC_CLF_Lite class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme__ubc_clf_lite_init() {

	$UBC_CLF_Lite = new UBC_WP_CLF_Lite();
	$UBC_CLF_Lite->init();

}/* after_setup_theme__ubc_clf_lite_init() */


/**
 * Customizer additions.
 */
require get_stylesheet_directory() . '/inc/customizer-ubc-wp-clf-lite.php';

/**
 * Theme Hook Alliance hooks
 *
 */
require get_stylesheet_directory() . '/inc/tha-hooks.php';


/**
 * content classes
 *
 */
require get_stylesheet_directory() . '/inc/content-classes.php';

/**
 * comments callback template
 *
 */
require get_stylesheet_directory() . '/inc/comments-callback.php';
